@@ -195,7 +195,7 @@ def asdict(obj: Dataclass, by_alias: bool = True, parser: Parser = DictParser())
     fields: Dict[str, Field] = get_fields_info(type(obj))
     dictionary: Dict[str, Any] = {}
     for key, field in fields.items():
-        if field.exclude:
+        if field.private:
             continue
 
         val = getattr(obj, key)
